==> oce_0.12.orig.tar.gz: oce-OCE-0.12/src/PDataStd/PDataStd_Variable.cxx <==
// Created on: 1997-12-10
// Created by: Denis PASCAL
// Copyright (c) 1997-1999 Matra Datavision
// Copyright (c) 1999-2012 OPEN CASCADE SAS
//
// The content of this file is subject to the Open CASCADE Technology Public
// License Version 6.5 (the "License"). You may not use the content of this file
// except in compliance with the License. Please obtain a copy of the License
// at http://www.opencascade.org and read it completely before using this file.
//
// The Initial Developer of the Original Code is Open CASCADE S.A.S., having its
// main offices at: 1, place des Freres Montgolfier, 78280 Guyancourt, France.
//
// The Original Code and all software distributed under the License is
// distributed on an "AS IS" basis, without warranty of any kind, and the
// Initial Developer hereby disclaims all such warranties, including without
// limitation, any warranties of merchantability, fitness for a particular
// purpose or non-infringement. Please see the License for the specific terms
// and conditions governing the rights and limitations under the License.


#include <PDataStd_Variable.ixx>

//=======================================================================
//function : PDataStd_Variable
//purpose  : 
//=======================================================================

PDataStd_Variable::PDataStd_Variable()
{
}

//=======================================================================
//function : PDataStd_Variable
//purpose  : 
//=======================================================================

PDataStd_Variable::PDataStd_Variable(const Standard_Boolean constant)
{
  Constant(constant);
}

//=======================================================================
//function : Constant
//purpose  : 
//=======================================================================

void PDataStd_Variable::Constant(const Standard_Boolean status) 
{
  isConstant = status;
}
//=======================================================================
//function : Constant
//purpose  : 
//=======================================================================
Standard_Boolean PDataStd_Variable::Constant() const
{
  return isConstant;
}
//=======================================================================
//function : Unit
//purpose  : 
//=======================================================================

void PDataStd_Variable::Unit(const Handle(PCollection_HAsciiString)& unit) 
{
  myUnit = unit;
}
//=======================================================================
//function : Unit
//purpose  : 
//=======================================================================
Handle(PCollection_HAsciiString) PDataStd_Variable::Unit() const
{
  return myUnit;
}

==> oce_0.15.orig.tar.gz: oce-OCE-0.15/src/PDataStd/PDataStd_Variable.cxx <==
// Created on: 1997-12-10
// Created by: Denis PASCAL
// Copyright (c) 1997-1999 Matra Datavision
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and / or modify it
// under the terms of the GNU Lesser General Public version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <PDataStd_Variable.ixx>

//=======================================================================
//function : PDataStd_Variable
//purpose  : 
//=======================================================================

PDataStd_Variable::PDataStd_Variable() : isConstant(Standard_False)
{
}

//=======================================================================
//function : PDataStd_Variable
//purpose  : 
//=======================================================================

PDataStd_Variable::PDataStd_Variable(const Standard_Boolean constant)
{
  Constant(constant);
}

//=======================================================================
//function : Constant
//purpose  : 
//=======================================================================

void PDataStd_Variable::Constant(const Standard_Boolean status) 
{
  isConstant = status;
}
//=======================================================================
//function : Constant
//purpose  : 
//=======================================================================
Standard_Boolean PDataStd_Variable::Constant() const
{
  return isConstant;
}
//=======================================================================
//function : Unit
//purpose  : 
//=======================================================================

void PDataStd_Variable::Unit(const Handle(PCollection_HAsciiString)& unit) 
{
  myUnit = unit;
}
//=======================================================================
//function : Unit
//purpose  : 
//=======================================================================
Handle(PCollection_HAsciiString) PDataStd_Variable::Unit() const
{
  return myUnit;
}
